from json import dumps
from requests import get


class YasirPediaApi:
    def __init__(self):
        self.base_url = "https://yasirapi.eu.org"

    def google(self, query: str):
        try:
            url = f"{self.base_url}/google?q={query}"
            response = get(url, timeout=15).json()
            return dumps(response, indent=2)
        except Exception as e:
            return f"An error occured report on @YasirArisM\n\n{e}"

    def textpro(self, text: str, link: str):
        try:
            url = f"{self.base_url}/textpro?q={text}&url={link}"
            response = get(url, timeout=15).json()
            return dumps(response, indent=2)
        except Exception as e:
            return f"An error occured report on @YasirArisM\n\n{e}"

    def kbbi(self, kata: str):
        try:
            url = f"{self.base_url}/kbbi?kata={kata}"
            response = get(url, timeout=15).json()
            return dumps(response, indent=2)
        except Exception as e:
            return f"An error occured report on @YasirArisM\n\n{e}"

    def lk21(self, query: str):
        try:
            url = f"{self.base_url}/lk21?q={query}"
            response = get(url, timeout=15).json()
            return dumps(response, indent=2)
        except Exception as e:
            return f"An error occured report on @YasirArisM\n\n{e}"

    def imdb_search(self, query: str):
        try:
            url = f"{self.base_url}/imdb-search?q={query}"
            response = get(url, timeout=15).json()
            return dumps(response, indent=2)
        except Exception as e:
            return f"An error occured report on @YasirArisM\n\n{e}"

    def fbdl(self, link: str):
        try:
            url = f"{self.base_url}/fbdl?link={link}"
            response = get(url, timeout=15).json()
            return dumps(response, indent=2)
        except Exception as e:
            return f"An error occured report on @YasirArisM\n\n{e}"

    def terbit21(self, query: str):
        try:
            url = f"{self.base_url}/terbit21?q={query}"
            response = get(url, timeout=15).json()
            return dumps(response, indent=2)
        except Exception as e:
            return f"An error occured report on @YasirArisM\n\n{e}"


from yasirapi import YasirPediaApi

req = YasirPediaApi()

print(req.google("Mengapa cewek susah dimengerti."))
"""
{
  "info": "Join telegram channel @YasirPediaChannel for updates.",
  "result": [
    {
      "link": "...",
      "snippet": "...",
      "title": "...",
    }
  ],
  "success": ...,
  "creator": "Yasir Aris M"
}
"""



import setuptools


with open("README.md", "r") as txt:
    long_description = txt.read()

setuptools.setup(
    name="yasirpedia-api",
    version="0.0.6",
    description="Official Python Wrapper for YasirPedia API.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
    author="Yasir Aris M",
    author_email="mail@yasir.eu.org",
    url="https://github.com/yasirarism/YasirPediaApi-Py",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
    ],
    install_requires=["requests"],
    python_requires=">=3.6",
)
